# OpenStack Member Spammer Detector


## Dependencies 

````bas
$ sudo apt update
$ sudo apt install python3-pip python3-dev build-essential libssl-dev libffi-dev python3-setuptools python3-venv 
libmysqlclient-dev
````


## Virtual Env

````bash
$ python3.6 -m venv env

$ source env/bin/activate

$ pip install -r requirements.txt

```` 